==> jc-1.4.0.tar.gz: java/awt/event/PaintEvent.h <==
// public class java.awt.event.PaintEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 776b1d1bd1ee2d3b java_awt_event_PaintEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_PaintEvent_H_
#define _JC_java_awt_event_PaintEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_PaintEvent$sub_refs	_jc_java_awt_event_PaintEvent$sub_refs;
typedef struct _jc_java_awt_event_PaintEvent$sub_nonrefs	_jc_java_awt_event_PaintEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_PaintEvent$refs	_jc_java_awt_event_PaintEvent$refs;
typedef struct _jc_java_awt_event_PaintEvent$nonrefs	_jc_java_awt_event_PaintEvent$nonrefs;
typedef struct _jc_java_awt_event_PaintEvent$object	_jc_java_awt_event_PaintEvent$object;

typedef struct _jc_java_awt_event_PaintEvent$fields_struct	_jc_java_awt_event_PaintEvent$fields_struct;
typedef const struct _jc_java_awt_event_PaintEvent$vmethods	_jc_java_awt_event_PaintEvent$vmethods;
typedef const struct _jc_java_awt_event_PaintEvent$vtable	_jc_java_awt_event_PaintEvent$vtable;
typedef const struct _jc_java_awt_event_PaintEvent$vtype	_jc_java_awt_event_PaintEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_PaintEvent$fields_struct {
	jlong	serialVersionUID;
	jint	PAINT;
	jint	PAINT__5fFIRST;
	jint	PAINT__5fLAST;
	jint	UPDATE;
};
extern _jc_java_awt_event_PaintEvent$fields_struct _jc_java_awt_event_PaintEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_PaintEvent$method$_init$4a3eb436f6edec8f(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Rectangle$object *);

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_java_awt_event_PaintEvent$method$getUpdateRect$eff5e57ad707a2aa(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_PaintEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *);
extern void _jc_java_awt_event_PaintEvent$method$setUpdateRect$00af7ecce2ea7bfd(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Rectangle$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$getUpdateRect$eff5e57ad707a2aa;
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$setUpdateRect$00af7ecce2ea7bfd;

// Virtual methods structure
struct _jc_java_awt_event_PaintEvent$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getUpdateRect$eff5e57ad707a2aa)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *);
	void	(*setUpdateRect$00af7ecce2ea7bfd)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Rectangle$object *);
};

// Vtable
struct _jc_java_awt_event_PaintEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_PaintEvent$vmethods	java_awt_event_PaintEvent;
};

// Vtype
struct _jc_java_awt_event_PaintEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_PaintEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_PaintEvent$sub_refs {
	struct _jc_java_awt_Rectangle$object	*updateRect;
};

// Reference instance fields (object)
struct _jc_java_awt_event_PaintEvent$refs {
    _jc_java_awt_event_PaintEvent$sub_refs	java_awt_event_PaintEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_PaintEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_PaintEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_PaintEvent$sub_nonrefs	java_awt_event_PaintEvent;
};

// Object instance structure
struct _jc_java_awt_event_PaintEvent$object {
	_jc_java_awt_event_PaintEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_PaintEvent$vtype	*vtype;
	_jc_java_awt_event_PaintEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_PaintEvent$vtype _jc_java_awt_event_PaintEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_PaintEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_PaintEvent$class_object;

#endif	/* _JC_java_awt_event_PaintEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/PaintEvent.h <==
// public class java.awt.event.PaintEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 776b1d1bd1ee2d3b java_awt_event_PaintEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_PaintEvent_H_
#define _JC_java_awt_event_PaintEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_PaintEvent$sub_refs	_jc_java_awt_event_PaintEvent$sub_refs;
typedef struct _jc_java_awt_event_PaintEvent$sub_nonrefs	_jc_java_awt_event_PaintEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_PaintEvent$refs	_jc_java_awt_event_PaintEvent$refs;
typedef struct _jc_java_awt_event_PaintEvent$nonrefs	_jc_java_awt_event_PaintEvent$nonrefs;
typedef struct _jc_java_awt_event_PaintEvent$object	_jc_java_awt_event_PaintEvent$object;

typedef struct _jc_java_awt_event_PaintEvent$fields_struct	_jc_java_awt_event_PaintEvent$fields_struct;
typedef const struct _jc_java_awt_event_PaintEvent$vmethods	_jc_java_awt_event_PaintEvent$vmethods;
typedef const struct _jc_java_awt_event_PaintEvent$vtable	_jc_java_awt_event_PaintEvent$vtable;
typedef const struct _jc_java_awt_event_PaintEvent$vtype	_jc_java_awt_event_PaintEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_PaintEvent$fields_struct {
	jlong	serialVersionUID;
	jint	PAINT;
	jint	PAINT__5fFIRST;
	jint	PAINT__5fLAST;
	jint	UPDATE;
};
extern _jc_java_awt_event_PaintEvent$fields_struct _jc_java_awt_event_PaintEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_PaintEvent$method$_init$4a3eb436f6edec8f(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_java_awt_event_PaintEvent$method$getUpdateRect$eff5e57ad707a2aa(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_PaintEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_PaintEvent$method$setUpdateRect$00af7ecce2ea7bfd(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$getUpdateRect$eff5e57ad707a2aa;
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_PaintEvent$method_info$setUpdateRect$00af7ecce2ea7bfd;

// Virtual methods structure
struct _jc_java_awt_event_PaintEvent$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getUpdateRect$eff5e57ad707a2aa)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *) _JC_JCNI_ATTR;
	void	(*setUpdateRect$00af7ecce2ea7bfd)(_jc_env *, struct _jc_java_awt_event_PaintEvent$object *, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_PaintEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_PaintEvent$vmethods	java_awt_event_PaintEvent;
};

// Vtype
struct _jc_java_awt_event_PaintEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_PaintEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_PaintEvent$sub_refs {
	struct _jc_java_awt_Rectangle$object	*updateRect;
};

// Reference instance fields (object)
struct _jc_java_awt_event_PaintEvent$refs {
    _jc_java_awt_event_PaintEvent$sub_refs	java_awt_event_PaintEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_PaintEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_PaintEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_PaintEvent$sub_nonrefs	java_awt_event_PaintEvent;
};

// Object instance structure
struct _jc_java_awt_event_PaintEvent$object {
	_jc_java_awt_event_PaintEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_PaintEvent$vtype	*vtype;
	_jc_java_awt_event_PaintEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_PaintEvent$vtype _jc_java_awt_event_PaintEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_PaintEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_PaintEvent$class_object;

#endif	/* _JC_java_awt_event_PaintEvent_H_ */
